# -*- coding: utf-8 -*-

"""
legit.helpers
~~~~~~~~~~~~~

Various Python helpers.
"""


import os


def find_path_above(*names):
    """Attempt to locate given path by searching parent dirs."""

    path = '.'

    while os.path.split(os.path.abspath(path))[1]:
        for name in names:
            joined = os.path.join(path, name)
            if os.path.exists(joined):
                return os.path.abspath(joined)
        path = os.path.join('..', path)




# -*- coding: utf-8 -*-

"""
legit.core
~~~~~~~~~~

This module provides the basic functionality of legit.
"""

# from clint import resources

__version__ = '0.0.9'
__author__ = 'Kenneth Reitz'
__license__ = 'BSD'


# resources.init('kennethreitz', 'legit')
# resources.user.write('config.ini', "we'll get there.")